clear;
tic

iterations = 1000;       %# of iterations performed for each Eb/N0 value
K = 100;                  %# of info bits
Eb_db_vector = 0:7;       %Range of Eb/N0 values   -> N_0 = 1 throughout

outer_its = 1;
for Eb_db = Eb_db_vector
    
    Eb = 10^(Eb_db/10);        %convert to linear units
    Es = Eb/2;                 %because R=1/2, i.e., half info bit per symbol
    
    bit_error = 0;
    
    for its = 1:iterations
        
        info_bits = round(rand(1,K));
        codeword = encode_75_function(info_bits);        
        
        %define RX signal
        %symbol is sqrt(Es)*codeword plus noise
        %length is 2K+2 because two additional zero's are transmitted at
        %end to terminate in state 00
        z =  sqrt(Es) * codeword + 1/sqrt(2) * randn(1,2*(K+2));  %noise variance =1/2  ->  N_0 = 1

        
        %FILL IN THE ALGORITHM HERE
        
                
        %Surviving path into terminal 00 (s00) should be of length (K+2)
        %ML codeword estimate is first K bits of surviving path into terminal 00
        %state
        estimate = s00(1:K);
        
        %Following line performs brute-force decoding; can be used to check
        %correctness of your code
        %temp = bruteforce_decoding_75(z,K)
        %difference = sum(abs(temp - estimate))

        %compute # of bit errors
        bit_error = bit_error + sum(abs(estimate-info_bits));        
        
        
    end;
        
    prob_bit(outer_its) = bit_error / (K*iterations);
    outer_its = outer_its + 1;
end;

%Q(z) = .5 * erfc(z/sqrt(2))
Eb_db_vector2 = min(Eb_db_vector):12;
%uncoded bit error
uncoded_bit = .5*erfc(sqrt(10.^(Eb_db_vector2/10)));
%nearest neighbor approximation
nn = .5*erfc(sqrt(2.5*10.^(Eb_db_vector/10)));

semilogy(Eb_db_vector, prob_bit, 'b');
hold on;
semilogy(Eb_db_vector2, uncoded_bit, 'b--');
hold on;
semilogy(Eb_db_vector, nn, 'g');
legend ('Bit - Coded', 'Bit - Uncoded', 'Nearest Neighbor');
grid on;

[Eb_db_vector' prob_bit']

toc